Downloads files of a Zenodo repository. If the repository is in restricted access, a token (argument token) must be provided.

zen_download_files(record_id, token, path = ".", files = NULL)

Arguments

record_id

a character of length 1. The Zenodo identifier of the repository (7 numbers). Can be found on the URL of the repository

token

a character of length 1. A token generated by Zenodo to access files of a restricted access.

path

a character of length 1. The folder in which files will be saved.

files

a character vector. If one or several files are provided, only these files will be downloaded. If NULL (default) all files will be downloaded.

Value

No returned value.

Examples

# List files available in the repo: https://zenodo.org/record/7936568 ----
zen_list_files("7936568")
#> [1] "content" "content" "content" "content" "content" "content" "content"

if (FALSE) { # \dontrun{
# Download one file ----
zen_download_files("7936568", files = "FORCIS_pump_v03_14062023.csv")

# Download all files ----
zen_download_files("7936568")
} # }